package com.planetes;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.FloatBuffer;

import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.opengles.GL10;
import android.opengl.GLU;
import android.opengl.GLSurfaceView.Renderer;

public class GlRenderer implements Renderer {

	private astroList 	stars;
	
	public void DrawCircle(GL10 gl,point p,float r,point color) {
		FloatBuffer vertexBuffer;
		float vertices[] = new float[722];
    	for (int i = 0; i < 361; i++){
    		vertices[2*i]=(float)(r*Math.cos(i*Math.PI/180)+p.getX());
    		vertices[2*i+1]=(float)(r*Math.sin(i*Math.PI/180)+p.getY());
    	}
    	
        // a float has 4 bytes so we allocate for each coordinate 4 bytes
		ByteBuffer vertexByteBuffer = ByteBuffer.allocateDirect(vertices.length * 4);
		vertexByteBuffer.order(ByteOrder.nativeOrder());
		
		// allocates the memory from the byte buffer
		vertexBuffer = vertexByteBuffer.asFloatBuffer();
		
		// fill the vertexBuffer with the vertices
		vertexBuffer.put(vertices);

		// set the cursor position to the beginning of the buffer
		vertexBuffer.position(0);
		
		gl.glEnableClientState(GL10.GL_VERTEX_ARRAY);

		// set the colour for the circle
		gl.glColor4f(color.getX(),color.getY(),color.getZ(),0.5f);
		// Point to our vertex buffer
		gl.glVertexPointer(2, GL10.GL_FLOAT, 0, vertexBuffer);
		// Draw the vertices as polygon
		gl.glDrawArrays(GL10.GL_TRIANGLE_FAN , 0, vertices.length/2);

		gl.glDisableClientState(GL10.GL_VERTEX_ARRAY);
	}

	
	public GlRenderer() {
		stars = new astroList(5);
	}

	public void onDrawFrame(GL10 gl) {
		stars.Move();
		gl.glClear(GL10.GL_COLOR_BUFFER_BIT | GL10.GL_DEPTH_BUFFER_BIT);
		gl.glClearColor(1.0f, 1.0f, 1.0f, 1.0f);
		for(int i = 0; i < stars.size(); i++){
			DrawCircle(gl,stars.planets.get(i).pos,stars.planets.get(i).rad,stars.planets.get(i).color);	
			for(int j = 0; j < stars.planets.get(i).tail.size(); j++){
				DrawCircle(gl,stars.planets.get(i).tail.get(j), 0.1f,stars.planets.get(i).color);
			}
		}
	}

	public void onSurfaceChanged(GL10 gl, int w, int h) {
		if (h == 0) { h = 1; }
		
		gl.glViewport(0, 0, w, h);
		gl.glOrthof(-w*1.0f/h , w*1.0f/h , -1.0f , 1.0f , -1.0f , 1.0f);
		GLU.gluPerspective(gl, 45.0f, (float)w / (float)h, -0.1f, 100.0f);
	}

	public void onSurfaceCreated(GL10 gl, EGLConfig config) {
	}

}
